@@ -15,7 +15,7 @@ sub test_gen {
     subtest $args{name} => sub {
         my $res;
         my %fargs = (
-            name       => 'foo',
+            name       => $args{func_name} // 'foo',
             install    => $args{install} // 0,
             dbh        => $args{dbh} // $main::dbh,
             table_name => $args{table_name},
@@ -64,7 +64,7 @@ sub test_gen {
 }
 
 sub gen_test_data {
-    my (undef, $dbpath) = tempfile('tempXXXXX', OPEN => 0);
+    my (undef, $dbpath) = tempfile(undef, OPEN => 0);
     diag "dbpath = $dbpath";
     my $dbh = DBI->connect("dbi:SQLite:dbname=$dbpath") or die $DBI::errstr;
 
